<?php

/**
 * Create a visualization or table view from given datablock
 *
 * @category    Ssr
 * @package     Ssr
 * @subpackage  DatablockListViewer
 * @version     Release: 1.1
 * @since       Class available since Release 1.1.1
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_DatablockListViewer {

    /**
     * Create a datablock viewer
     * @param Ssr_Datablock $datablock  A datablock to visualize
     * @param mysqli $db 
     */
    public function __construct($datablock, $db) {
        $this->datablock = $datablock;
        $this->db = $db;
    }

    /**
     * The main call to generate the table
     * @param int $cellStart The first cell index
     * @param type $cellEnd The last cell index
     * @return string The generated table
     */
    public function view($cellStart, $cellEnd) {
        $tabldesc = $this->datablock->getTableDescriptor();
        $pricol = $tabldesc->getPrimaryColumnName();
        $o = "<table class=\"{$this->tableclass}\">";
        $maxCell = $this->datablock->countCells();
        if ($cellStart < 0)
            $cellStart = 0;
        for ($i = $cellStart; $i < $cellEnd && $i < $maxCell; $i++) {
            $cell = $this->datablock->getCell($i);
            $o .= "<tr valign=\"top\">";
            if ($this->datablock->cellMatchesDatabase($i, $this->db))
                $o .= "<td>></td>";
            else if ($this->datablock->cellMatchesDatabase($i, $this->db, -1))
                $o .= '<td><</td>';
            else
                $o.= "<td>?</td>";
            $o .= "<td><strong>{$cell['col']} ($pricol={$cell['row']})</strong><br />
                        {$cell['pre']}</td>";
            $o .= "<td>{$cell['post']}</td>";
            $o .= '</tr>';
        }
        $o .= "</table>";
        return $o;
    }

    /**
     * Get the current table css class name
     * @return string
     */
    public function getTableclass() {
        return $this->tableclass;
    }

    /**
     * Set the table css class name
     * @param string $tableclass A valid css class name
     */
    public function setTableclass($tableclass) {
        $this->tableclass = $tableclass;
    }

    /**
     * @var Ssr_Datablock
     */
    private $datablock;
    private $tableclass = '';

    /**
     * @var mysqli
     */
    private $db;

}

?>
