<?php

/**
 * Create a visualization or table view from given datablock
 *
 * @category    Ssr
 * @package     Ssr
 * @subpackage  DatablockTableViewer
 * @version     Release: 1.0
 * @since       Class available since Release 1.0
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_DatablockTableViewer {

    /**
     * Create a datablock viewer
     * @param Ssr_Datablock $datablock  A datablock to visualize
     * @param mysqli $db 
     */
    public function __construct($datablock, $db) {
        $this->datablock = $datablock;
        $this->db = $db;
    }

    /**
     * The main call to generate the table
     * @param int $cellStart The first cell index
     * @param type $cellEnd The last cell index
     * @return string The generated table
     */
    public function view($cellStart, $cellEnd) {
        $th = '<tr><th></th><th>Cell#</th>';
        $tabldesc = $this->datablock->getTableDescriptor();
        $pricol = $tabldesc->getPrimaryColumnName();
        $colmap = array();
        for ($i = 0; $i < $tabldesc->size(); $i++) {
            $colmap[$tabldesc->getColumnName($i)] = '';
            $th .= "<th>{$tabldesc->getColumnName($i)} {$tabldesc->getColumnKey($i)}</th>";
        }
        $th .= '</tr>';

        $o = "<table class=\"{$this->tableclass}\"><thead>$th</thead>
                <tfoot>$th</tfoot>";
        $maxCell = $this->datablock->countCells();
        if ($cellStart < 0)
            $cellStart = 0;
        for ($i = $cellStart; $i < $cellEnd && $i < $maxCell; $i++) {
            $cell = $this->datablock->getCell($i);
            $tmap = $colmap;
            $tmap[$pricol] = $cell['row'];
            $tmap[$cell['col']] = "<div style=\"color:gray\">{$cell['pre']}</div>{$cell['post']}";
            $o .= "<tr>";
            if ($this->datablock->cellMatchesDatabase($i, $this->db))
                $o .= "<td>></td>";
            else if ($this->datablock->cellMatchesDatabase($i, $this->db, -1))
                $o .= '<td><</td>';
            else
                $o.= "<td></td>";
            $o .= "<td>$i</td>";
            foreach ($tmap as $v)
                $o .= "<td>$v</td>";
            $o .= '</tr>';
        }
        $o .= "</table>";
        return $o;
    }

    /**
     * Get the current table css class name
     * @return string
     */
    public function getTableclass() {
        return $this->tableclass;
    }

    /**
     * Set the table css class name
     * @param string $tableclass A valid css class name
     */
    public function setTableclass($tableclass) {
        $this->tableclass = $tableclass;
    }

    /**
     * @var Ssr_Datablock
     */
    private $datablock;
    private $tableclass = '';

    /**
     * @var mysqli
     */
    private $db;

}

?>
