<?php

//---------------------------------------------------------------------------------------------------------
// SETUP REQUIRED DEPENDENCIES AND FEATURES
//---------------------------------------------------------------------------------------------------------
require 'Error.php';
require 'Warning.php';
require 'Ssr.php';
require 'Api/TableFilter.php';
require 'Api/Execute.php';
require 'UI/Ajax.php';

//---------------------------------------------------------------------------------------------------------
// SETUP INSTALLER (ACTIVATE, DEACTIVATE, INSTALL, UNINSTALL)
//---------------------------------------------------------------------------------------------------------

/**
 * Initialize SSR
 * 
 * Class is used during activation, install, deactivation
 *
 * @category    Ssr
 * @package     Ssr
 * @subpackage  Init
 * @version     Release: 1.0
 * @since       Class available since Release 1.0
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_Init {

    /**
     * Register UI elements and js scripts for the admin panel
     */
    public static function initAdminPanel() {
        require 'UI/AdminPanel.php';
        add_management_page('Safe Search Replace (SSR) Admin Panel', 'Safe Search Replace', 5, 'ssr-main', 'Ssr_UI_AdminPanel::create');

        wp_register_script('ssr_js', WP_PLUGIN_URL . '/safe-search-replace/js/ssr.js');
        wp_enqueue_script('ssr_js');

        $ssr_version = get_option('SSR_VERSION');
        if ($ssr_version === false) {
            self::on_install();
        } else if ($ssr_version != Ssr::getVersion())
            self::on_update();
    }

    /**
     * Set up tables, add options, etc. - All preparation that only needs to be done once
     */
    public static function on_activate() {
        self::executeCLAction('activate');
    }

    /**
     * Do nothing like removing settings, etc. 
     * The user could reactivate the plugin and wants everything in the state before activation.
     * Take a constant to remove everything, so you can develop & test easier.
     */
    public static function on_deactivate() {
        self::executeCLAction('deactivate');
    }

    /**
     * Any operation required in case of an update
     */
    public static function on_update() {
        self::executeCLAction('update');
        update_option('SSR_VERSION', Ssr::getVersion());
    }

    /**
     * Remove/Delete everything - If the user wants to uninstall, then he wants the state of origin.
     */
    public static function on_uninstall() {
        // important: check if the file is the one that was registered with the uninstall hook (function)
        if (__FILE__ != WP_UNINSTALL_PLUGIN)
            return;
        self::executeCLAction('uninstall');
        delete_option('SSR_VERSION');
    }

    /**
     * Sets up database if this plugin is installed.
     */
    public static function on_install() {
        self::executeCLAction('install');
        add_option('SSR_VERSION', Ssr::getVersion());
    }

    /**
     * Execute the CLAction
     * @param string $action 
     */
    private static function executeCLAction($action) {
        require 'Utils/DataTransfer.php';
        $transfer = new Ssr_Utils_DataTransfer(Ssr::getCLActionURL());
        $param = array('clversion' => Ssr::getVersion(), 'clname' => 'SSR', 'claction' => $action);
        $transfer->submit($param);
    }

}

add_action('wp_ajax_ssr_preview_selection', 'Ssr_UI_Ajax::createTableFilterPreview');