<?php

/**
 * This class initializes an admin panel being used by WP admin area.
 *
 * @category    Ssr
 * @package     Ssr_UI
 * @subpackage  AdminPanel
 * @version     Release: 1.0
 * @since       Class available since Release 1.0
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_UI_AdminPanel {

    /**
     * Create an admin panel
     */
    public function __construct() {

        echo '<div class="wrap">' .
        '<div id="icon-tools" class="icon32">' .
        '</div>';
        echo '<h2>' . __('Safe Search Replace', 'ssr') . '</h2><br />';

        $tabs['filter']['title'] = __('Search & Replace', 'ssr');
        $tabs['filter']['baseclass'] = 'TableFilter';
        $tabs['list']['title'] = __('Previous Operations', 'ssr');
        $tabs['list']['baseclass'] = 'History';
        $tabs['reports']['title'] = __('Reports', 'ssr');
        $tabs['reports']['baseclass'] = 'Reports';

        if (!isset($_GET['tab']) || empty($_GET['tab']))
            $_GET['tab'] = 'filter';

        echo '<h3 class="nav-tab-wrapper">';
        foreach ($tabs as $name => $obj) {
            $title = $obj['title'];
            $active = '';
            if ($_GET['tab'] == $name)
                $active = 'nav-tab-active';
            echo '<a href="?' . http_build_query(array('page' => $_GET['page'], 'tab' => $name)) . "\" class=\"nav-tab $active\">$title</a>";
        }
        echo '</h3>';

        foreach ($tabs as $name => $obj) {
            if ($_GET['tab'] == $name) {
                require "{$obj['baseclass']}.php";
                call_user_func("Ssr_UI_{$obj['baseclass']}::create");
            }
        }
    }

    /**
     * Create an admin panel. It also registers the admin footer.
     * 
     * @return Ssr_UI_AdminPanel 
     */
    public static function create() {
        add_filter('admin_footer_text', 'Ssr_UI_AdminPanel::printFooter');
        return new Ssr_UI_AdminPanel();
    }

    /**
     * Get a new mysqli connection
     * @global wpdb $wpdb
     * @return mysqli 
     */
    public static function getMysqliConnection() {
        global $wpdb;
        return new mysqli($wpdb->dbhost, $wpdb->dbuser, $wpdb->dbpassword, self::getMysqliDbName());
    }

    /**
     * Get the current database name. Used to increase security.
     * @global wpdb $wpdb
     * @return string 
     */
    public static function getMysqliDbName() {
        return 'ows_index';
        global $wpdb;
        return $wpdb->dbname;
    }

    /**
     * Print the admin footer
     * @return string
     */
    public static function printFooter() {
        return '<p id="footer-left" class="alignleft">
                <span id="footer-thankyou">' .
                sprintf(__("Thank you for using %s",'ssr'), '<a href="http://cs.benjaminsommer.com/safe-search-replace/wp/" target="_blank">Safe Search Replace</a> (SSR)') .
                '
                </span>
                •
                <a href="http://cs.benjaminsommer.com/safe-search-replace/wp/" target="_blank">' . __('Documentation', 'ssr') . '</a>
                •
                <a href="http://wordpress.org/tags/safe-search-replace?forum_id=10" target="_blank">' . __('Feedback', 'ssr') . '</a>
                •
                <a href="http://cs.benjaminsommer.com/safe-search-replace/wp/" target="_blank">' . __('Credits', 'ssr') . '</a>
                </p>
                <p id="footer-ssr" class="alignright">' . sprintf(__('Version %s', 'ssr'), Ssr::getVersion()) . '</p>
                <div class="clear"></div>';
    }

}

?>
