<?php

/**
 * List and manage all past operations from the user side (UI)
 *
 * @category    Ssr
 * @package     Ssr_UI
 * @subpackage  History
 * @version     Release: 1.1
 * @since       Class available since Release 1.0
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_UI_History {

    /**
     * Initialize this UI element via callbacks (cleaner way on the caller side)
     * @return Ssr_UI_History 
     */
    public static function create() {
        return new Ssr_UI_History();
    }

    /**
     * Create a new history panel (past operations).
     */
    public function __construct() {
        $this->dbname = Ssr_UI_AdminPanel::getMysqliDbName();
        $this->db = Ssr_UI_AdminPanel::getMysqliConnection();

        if(isset($_GET['remove'])) {
            $path = SSR_DATA .'exec/'.$_GET['remove'];
            if(file_exists($path)) {
                unlink($path);
                echo '<div id="message" class="updated"><p>';
                printf(__('Removed Task #%s','ssr'),  basename($path, '.descriptor.xml'));
                echo '</p></div>';
            }
            unset($_GET['remove']);
        }
        
        if (isset($_GET['view']) && !empty($_GET['view'])) {
            if (isset($_GET['execforw']) || isset($_GET['execback']))
                $this->executeBlock();
            $this->printDescriptor();
        } else if (isset($_GET['details'])) {
            $this->printDetails();
        } else
            $this->printList();
    }

    /**
     * Print a list of past operations along with their properties.
     * @uses    Ssr_DataDescriptor
     */
    private function printList() {
        $dir = SSR_PATH . 'data/exec/';
        $files_ = scandir($dir);
        $files = array();
        foreach ($files_ as $filename) {
            $name = basename($filename, '.descriptor.xml');
            if ($name != $filename)
                $files[filemtime($dir . $filename)] = $filename;
        }
        krsort($files);
        
        if(sizeof($files)==0) {
            echo '<div id="message" class="updated"><p>';
            _e('No past operations have been found. Use the `Search & Replace` tool to create table filter and operations.','ssr');
            echo '</div>';
            return;
        }
        
        echo "<h3>" . __('Listing: Past Operations', 'ssr') . "</h3>";
        echo '<table class="widefat">
                <thead>
                    <tr>
                        <th>' . __('Task ID', 'ssr') . '</th>
                        <th>' . __('Name', 'ssr') . '</th>
                        <th>' . __('Description', 'ssr') . '</th>
                        <th>' . __('Selector', 'ssr') . '</th>
                        <th>' . __('Filter', 'ssr') . '</th>
                        <th>' . __('Blocks', 'ssr') . '</th>
                        <th>' . __('Cells', 'ssr') . '</th>
                        <th>' . __('Date', 'ssr') . '</th>
                        <th>' . __('Report', 'ssr') . '</th>
                    </tr>
                </thead>
                <tfoot>
                    <tr>
                        <th>' . __('Task ID', 'ssr') . '</th>
                        <th>' . __('Name', 'ssr') . '</th>
                        <th>' . __('Description', 'ssr') . '</th>
                        <th>' . __('Selector', 'ssr') . '</th>
                        <th>' . __('Filter', 'ssr') . '</th>
                        <th>' . __('Blocks', 'ssr') . '</th>
                        <th>' . __('Cells', 'ssr') . '</th>
                        <th>' . __('Date', 'ssr') . '</th>
                        <th>' . __('Report', 'ssr') . '</th>
                    </tr>
                </tfoot>
                <tbody>';

        
        
        foreach ($files as $filename) {
            $name = basename($filename, '.descriptor.xml');
            $datadesc = Ssr_DataDescriptor::createFromFile($dir . $filename);
            echo '<tr onmouseover="ssr_visible(\'ssr-task-'.$name.'\')" onmouseout="ssr_hidden(\'ssr-task-'.$name.'\')">';
            echo "<td>$name</td>";
            echo "<td>{$datadesc->getName()}";
            echo '<div id="ssr-task-'.$name.'" style="visibility:hidden">
                    <a href="?' . http_build_query(array_merge($_GET, array('details' => $filename))) . '">'.__('Details','ssr').'</a> | 
                    <a href="?' . http_build_query(array_merge($_GET, array('view' => $filename))) . '">'.__('View Data','ssr').'</a> | 
                    <a href="?' . http_build_query(array_merge($_GET, array('remove' => $filename))) . '">'.__('Delete','ssr').'</a></div>';
            echo "</td>";
            echo "<td>{$datadesc->getDescription()}</td>";
            echo "<td>{$datadesc->countSelectors()}</td>";
            echo "<td>{$datadesc->countFilter()}</td>";
            echo "<td>{$datadesc->countBlocks()}</td>";
            echo "<td>{$datadesc->countCells()}</td>";
            echo "<td>" . date(DateTime::ISO8601, filemtime($dir . $filename)) . "</td>";
            $reportName = $datadesc->getReportName();
            $report = basename($reportName, '.report');
            echo "<td><a href=\"?" . http_build_query(array('page' => $_GET['page'], 'tab' => 'reports', 'report' => $reportName)) . "\">$report</a></td>";
            echo '</tr>';
        }

        echo '</tbody>
           </table>';
    }
    
    private function printDetails() {
        $file = $_GET['details'];
        $name = basename($file,'.descriptor.xml');
        echo "<h3>" . sprintf(__('Details: Task #%s', 'ssr'),$name) . "</h3>";
        
        $datadesc = Ssr_DataDescriptor::createFromFile($path=SSR_DATA."exec/$file");
        
        echo '<table class="form-table">
            <tbody>
                <tr valign="top">
                    <th scope="row">' . __('Task Name', 'ssr') . '</th>
                    <td>' . $datadesc->getName() . '</td>
                </tr>
                <tr valign="top">
                    <td scope="row">' . __('Task Description', 'ssr') . '</td>
                    <td>' . $datadesc->getDescription() . '</td>
                </tr>
                <tr valign="top">
                    <td scope="row">' . __('Execution Date', 'ssr') . '</td>
                    <td>' . date(DateTime::ISO8601,filectime($path)) . '</td>
                </tr>
                <tr valign="top">
                    <td scope="row">' . __('Report Number', 'ssr') . '</td>
                    <td><a href="?' . http_build_query(array('page' => $_GET['page'], 'tab' => 'reports', 'report' => $reportName)) . '">'
                            . basename($datadesc->getReportName(),'.report') . '</a></td>
                </tr>
                <tr valign="top">
                    <td scope="row">' . __('Number of DataBlocks', 'ssr') . '</td>
                    <td>' . $datadesc->countBlocks() . '</td>
                </tr>
                <tr valign="top">
                    <td scope="row">' . __('Number of Table Cells', 'ssr') . '</td>
                    <td>' . $datadesc->countCells() . '</td>
                </tr>';
        if($datadesc->countSelectors()>0) {
            echo '<tr valign="top">
                        <td scope="row">' . __('List of Selectors', 'ssr') . '</td>
                        <td><ul>';
            for($i=0;$i<$datadesc->countSelectors();$i++) {
                $e = $datadesc->getSelector($i);
                echo "<li>{$e->getPattern()} (".__('Column','ssr').": {$e->getColumnName()})</li>";
            }
            echo '</ul></td></tr>';
        }
        if($datadesc->countFilter()>0) {
            echo '<tr valign="top">
                        <td scope="row">' . __('List of Filter', 'ssr') . '</td>
                        <td><ul>';
            for($i=0;$i<$datadesc->countFilter();$i++) {
                $e = $datadesc->getFilter($i);
                echo "<li>{$e->getSearchPattern()} >>> {$e->getReplacePattern()} (".__('Column','ssr').": {$e->getColumnName()})</li>";
            }
            echo '</ul></td></tr>';
        }
         echo '</tbody>
         </table>';
    }

    /**
     * Print and view a past data descriptor with all its child data blocks.
     * From here, past operations can be undone, or redone.
     * @uses    Ssr_DataDescriptor, Ssr_Datablock, Ssr_DatablockViewer
     */
    private function printDescriptor() {
        $viewer = 'TableViewer';
        if(isset($_GET['viewer']))
            $viewer = $_GET['viewer'];
        require SSR_PATH . "Ssr/Api/Datablock$viewer.php";

        $datadescFile = $_GET['view'];
        $taskid = basename($datadescFile, '.descriptor.xml');
        if (isset($_GET['blockid']))
            $blockid = $_GET['blockid'];
        else
            $blockid = 0;
        if (isset($_GET['cellstart']))
            $cellstart = $_GET['cellstart'];
        else
            $cellstart = 0;
        if (isset($_GET['cellend']))
            $cellend = $_GET['cellend'];
        else
            $cellend = 100;

        $file = SSR_DATA . "exec/$datadescFile";
        $datadesc = Ssr_DataDescriptor::createFromFile($file);

        $datablock = Ssr_Datablock::createFromFile($datadesc->getBlockPath($blockid));
         if($viewer == 'TableViewer')
            $blockviewer = new Ssr_DatablockTableViewer($datablock, $this->db);
        else $blockviewer = new Ssr_DatablockListViewer($datablock, $this->db);
        $blockviewer->setTableclass('widefat');

        echo "<div style=\"float:right\">";
        echo '<form action="" method="get">';

        echo "<small>";
        echo sprintf(__('Currently viewing task #%s', 'ssr'), $taskid);
        echo '</small>';
        echo ' | ';

        foreach ($_GET as $k => $v) {
            if ($k != 'blockid' && $k != 'cellend' && $k != 'cellstart')
                echo "<input type=\"hidden\" name=\"$k\" value=\"$v\" />";
        }
        echo __('Results', 'ssr') . ": <input type=\"text\" value=\"$cellstart\" name=\"cellstart\" size=\"7\" />
                    -> <input type=\"text\" value=\"$cellend\" name=\"cellend\" size=\"7\" />";
        if ($datadesc->countBlocks() > 1) {
            echo ' | <select name="blockid">';
            for ($i = 0; $i < $datadesc->countBlocks(); $i++) {
                echo "<option value=\"$i\" " . selected($i, $blockid, false) . ">" . sprintf(__('Block #%s', 'ssr'), $i) . "</option>";
            }
            echo '</select> ';
        }
        echo ' | <select name="viewer">';
            $viewers = array();
            $viewers['TableViewer'] = __('Table','ssr');
            $viewers['ListViewer'] = __('List','ssr');
            echo "<option>" . __('View As','ssr') . "</option>";
            foreach($viewers as $k=>$v)
                echo "<option value=\"$k\" " . selected($k, $viewer, false) . ">$v</option>";
        echo '</select> ';
        echo ' <input type="submit" value="' . __('Update View', 'ssr') . '" class="button-secondary" /> || ';

        echo '<input type="submit" value="' . __('Execute Forward', 'ssr') . '" class="button-primary" name="execforw" />';
        echo '<input type="submit" value="' . __('Execute Backward', 'ssr') . '" class="button-primary" name="execback" />';
        echo '</form>';
        echo "</div>";
        echo "<h3>" . __('Viewing: DataDescriptor & DataBlocks', 'ssr') . "</h3>";

        echo $blockviewer->view($cellstart, $cellend);
    }

    /**
     * Execute a previously chosen data block for given data descriptor.
     * Returns an updated or error messages.
     * @uses    Ssr_DataDescriptor, Ssr_Execute
     */
    private function executeBlock() {
        require_once SSR_PATH . 'Ssr/Api/Execute.php';

        $datadescFile = $_GET['view'];
        $taskid = basename($datadescFile, '.descriptor.xml');
        if (isset($_GET['blockid']))
            $blockId = $_GET['blockid'];
        else
            $blockId = 0;
        $file = SSR_PATH . "data/exec/$datadescFile";
        $datadesc = Ssr_DataDescriptor::createFromFile($file);
        $execute = new Ssr_Execute($datadesc, $this->db, SSR_PATH . 'data/exec/', SSR_PATH . 'data/reports/');
        if (isset($_GET['execforw'])) {
            unset($_GET['execforw']);
            $execute->exec($blockId, 1);
        } else if (isset($_GET['execback'])) {
            unset($_GET['execback']);
            $execute->exec($blockId, -1);
        }
        $report = $execute->getReportPath();

        if ($execute->countCellsFail() == 0) {
            echo '<div id="message" class="updated"><p>';
            printf(__('<strong>Executed block #%1$s</strong> from task #%2$s.', 'ssr'), $blockId, $taskid);
        } else {
            echo '<div id="message" class="error"><p>';
            printf(__('<strong>Executed %1$s/%2$s</strong> in block #%3$s from task #%4$s.', 'ssr'), $execute->countCellsOk(), $execute->countCellsFail(), $blockId, $taskid);
        }
        echo ' ';
        printf(__('See detailed report (%s)', 'ssr'), basename($report));
        echo '</p></div>';
    }

    /**
     *
     * @var mysqli
     */
    private $db;
    private $dbname;

}

?>
