<?php

/**
 * List all generated reports from past operations.
 *
 * @category    Ssr
 * @package     Ssr_UI
 * @subpackage  Reports
 * @version     Release: 1.1
 * @since       Class available since Release 1.0
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_UI_Reports {

    /**
     * Create a new UI to view reports. Used as callbacks.
     * @return Ssr_UI_Reports 
     */
    public static function create() {
        return new Ssr_UI_Reports();
    }

    /**
     * Initialize and create a new UI to view past reports.
     */
    public function __construct() {
        
        if(isset($_GET['remove'])) {
            $path = SSR_DATA .'reports/'.$_GET['remove'];
            if(file_exists($path)) {
                unlink($path);
                echo '<div id="message" class="updated"><p>';
                printf(__('Removed Report #%s','ssr'),  basename($path, '.report'));
                echo '</p></div>';
            }
            unset($_GET['remove']);
        }
        
        if (isset($_GET['report']) && !empty($_GET['report']))
            $this->printReport();
        else
            $this->printList();
    }

    /**
     * Print a list of past reports, along with detailed information.
     */
    private function printList() {
        $dir = SSR_PATH . 'data/reports/';
        $reports_ = scandir($dir);
        $reports = array();
        foreach ($reports_ as $filename) {
            $name = basename($filename, '.report');
            if ($name != $filename)
                $reports[filemtime($dir . $filename)] = $filename;
        }
        krsort($reports);
        
        if(sizeof($reports)==0) {
            echo '<div id="message" class="updated"><p>';
            _e('No reports have been found. Reports are automatically created as soon as tasks are carried out.','ssr');
            echo '</div>';
            return;
        }
        
        echo "<h3>" . __('Listing: Past Reports', 'ssr') . "</h3>";
        echo '<table class="widefat">
                <thead>
                    <tr>
                        <th>' . __('Report Number', 'ssr') . '</th>
                        <th>' . __('Date', 'ssr') . '</th>
                        <th>' . __('Excerpt', 'ssr') . '</th>
                    </tr>
                </thead>
                <tfoot>
                    <tr>
                        <th>' . __('Report Number', 'ssr') . '</th>
                        <th>' . __('Date', 'ssr') . '</th>
                        <th>' . __('Excerpt', 'ssr') . '</th>
                    </tr>
                </tfoot>
                <tbody>';

        
        foreach ($reports as $filename) {
            $name = basename($filename, '.report');
            echo '<tr  onmouseover="ssr_visible(\'ssr-report-'.$name.'\')" onmouseout="ssr_hidden(\'ssr-report-'.$name.'\')">';
            echo "<td>$name</td>";
            echo '<td>' . date(DateTime::ISO8601, filemtime($dir . $filename));
            echo '<div id="ssr-report-'.$name.'" style="visibility:hidden">
                    <a href="?' . http_build_query(array_merge($_GET, array('report' => $filename))) . '">'.__('View Full Report','ssr').'</a> | 
                    <a href="?' . http_build_query(array_merge($_GET, array('remove' => $filename))) . '">'.__('Delete','ssr').'</a></div>';
            echo '</td>';
            echo '<td>' . nl2br(file_get_contents($dir . $filename, null, null, null, 350)) . '...</td>';
            echo '</tr>';
        }

        echo '</tbody>
           </table>';
    }

    /**
     * Print the content of a chosen report
     */
    private function printReport() {
        $filename = $_GET['report'];
        $path = SSR_PATH . 'data/reports/' . $filename;
        $report = basename($filename, '.report');

        echo "<h3>";
        printf(__('View Report %s', 'ssr'), $report);
        echo "</h3>";
        echo nl2br(file_get_contents($path));
    }

}

?>
