<?php

/**
 * Set and get last warning.
 * 
 * This class is very much similar to Ssr_Error. See there for more details.
 *
 * @category    Ssr
 * @package     Ssr
 * @subpackage  Ssr_Warning
 * @version     Release: 2.10
 * @since       Class available since Release 2.10
 * @author      Benjamin Sommer <developer@benjaminsommer.com>
 */
class Ssr_Warning {

    /**
     * Set the current warning state and overwrite the last warning
     *
     * @param int       $errno      An unique warning identifier
     * @param string    $message      The warning message to be read by the user
     */
    public static function push($errno, $message) {
        $t['errno'] = $errno;
        $t['message'] = $message;
        self::$warn[] = (object) $t;
    }

    /**
     * Get the detailed warning message with warning number
     *
     * @return string   warning message 
     */
    public static function getLastWarning() {
        return end(self::$warn);
    }

    /**
     * Get the detailed warning message with warning number
     *
     * @return object   Last warning with ->warning and ->errno
     */
    public static function popLastWarning() {
        return array_pop(self::$warn);
    }

    /**
     * If the warning stack is not empty, so if it contains at least one warning
     *
     * @return bool
     */
    public static function haswarning() {
        return sizeof(self::$warn) > 0;
    }

    public static function printStack($ln=PHP_EOL) {
        foreach (self::$warn as $o)
            echo "Warning {$o->errno}: {$o->message}." . $ln;
    }

    /**
     * Clear the current warning state
     */
    public static function clear() {
        self::$warn = array();
    }

    private static $warn = array();

}

?>
